@@ -19,6 +19,6 @@
 
 LIBDIR = r'/usr/local/lib'
 DATADIR = r'/usr/local/share'
-BUILDDIR = r'/pobj/gst-devtools-1.24.11/build-mips64'
-SRCDIR = r'/pobj/gst-devtools-1.24.11/gst-devtools-1.24.11'
+BUILDDIR = r'/usr/obj/ports/gst-devtools-1.24.12/build-aarch64'
+SRCDIR = r'/usr/obj/ports/gst-devtools-1.24.12/gst-devtools-1.24.12'
 GST_VALIDATE_TESTSUITE_VERSION = '1.24'
